'use strict';

var lodash = require('lodash');

function _interopDefaultCompat (e) { return e && typeof e === 'object' && 'default' in e ? e : { default: e }; }

var lodash__default = /*#__PURE__*/_interopDefaultCompat(lodash);

function createAppIdResolver(octokitProvider) {
  const installationIdToAppId = /* @__PURE__ */ new Map();
  return async (request) => {
    const installationId = lodash__default.default.get(
      request.body,
      "installation.id"
    );
    if (!installationId || typeof installationId !== "number") {
      return void 0;
    }
    let appIdPromsie = installationIdToAppId.get(installationId);
    if (appIdPromsie) {
      return await appIdPromsie;
    }
    const repositoryUrl = lodash__default.default.get(
      request.body,
      "repository.html_url"
    );
    if (!repositoryUrl || typeof repositoryUrl !== "string") {
      return void 0;
    }
    const octokit = await octokitProvider.getOctokit(repositoryUrl);
    appIdPromsie = octokit.rest.apps.getInstallation({ installation_id: installationId }).then((response) => Number(response.data.app_id)).catch(() => void 0);
    installationIdToAppId.set(installationId, appIdPromsie);
    return await appIdPromsie;
  };
}

exports.createAppIdResolver = createAppIdResolver;
//# sourceMappingURL=createAppIdResolver.cjs.js.map
